// #ifdef HAVE_CONFIG_H
// # include "config.h"
// #endif

#include <gtk/gtk.h>
#include <sqlite3.h>

#include "callbacks.h"
#include "interface.h"
#include "support.h"
#include "lpweekly.h"
GtkWidget *lp_dialog_filechooser;
static GtkFileFilter *filefilter_selected;
sqlite3 *db;

static void
lp_create_database (gchar * filename)
{
  int rc;
  rc = sqlite3_open (filename, &db);
  if (rc)
    {
      fprintf (stderr, "Can't open database: %s\n", sqlite3_errmsg (db));
      sqlite3_close (db);
      exit (1);
    }
  // printf();
}

static void
lp_set_currentdate (GtkWidget * lp_window_main)
{
  printf ("date:\n");
  // get current date and set screen date to this weeks monday

  GDate *mydate = g_date_new ();
  g_date_set_time (mydate, time (NULL));


  GtkWidget *lp_main_label_date =
    lookup_widget (lp_window_main, "lp_main_label_date");
  gchar mydate_string[101];
  g_date_strftime (mydate_string, 100, "%Y/%m/%d\0", mydate);
  printf ("current date:%s\n", mydate_string);
  gtk_label_set_text (GTK_LABEL (lp_main_label_date), mydate_string);

  GDateWeekday day_of_week = g_date_get_weekday (mydate);
  int monday_difference = day_of_week - 1;	// to get
  // difference 
  // between 
  // monday
  // and
  // current 
  // day_of_week
  g_date_subtract_days (mydate, monday_difference);
  g_date_strftime (mydate_string, 100, "%Y/%m/%d\0", mydate);
  printf ("current date:%s\n", mydate_string);
  gtk_label_set_text (GTK_LABEL (lp_main_label_date), mydate_string);
  g_object_set_data (lp_main_label_date, "date", mydate);
}

static void
lp_on_back_week_activate (GtkWidget * widget)
{
  GtkWidget *lp_main_label_date =
    lookup_widget (widget, "lp_main_label_date");
  GDate *mydate = g_object_get_data (lp_main_label_date, "date");
  g_date_subtract_days (mydate, 7);

  gchar mydate_string[101];
  g_date_strftime (mydate_string, 100, "%Y/%m/%d\0", mydate);
  gtk_label_set_text (GTK_LABEL (lp_main_label_date), mydate_string);
  g_object_set_data (lp_main_label_date, "date", mydate);
  lp_setup_weekly (widget, &db);
}


static void
lp_on_forward_week_activate (GtkWidget * widget)
{
  GtkWidget *lp_main_label_date =
    lookup_widget (widget, "lp_main_label_date");
  GDate *mydate = g_object_get_data (lp_main_label_date, "date");
  g_date_add_days (mydate, 7);

  gchar mydate_string[101];
  g_date_strftime (mydate_string, 100, "%Y/%m/%d\0", mydate);
  gtk_label_set_text (GTK_LABEL (lp_main_label_date), mydate_string);
  g_object_set_data (lp_main_label_date, "date", mydate);
  lp_setup_weekly (widget, &db);
}

static int
lessonplan_sqlite3_callback (void *NotUsed, int argc, char **argv,
			     char **azColName)
{
  int i;
  for (i = 0; i < argc; i++)
    {
      printf ("%s = %s\n", azColName[i], argv[i] ? argv[i] : "NULL");
    }
  printf ("\n");
  return 0;
}

void
lp_open_database (gchar * filename, GtkWidget * lp_window_main)
{
  int rc = SQLITE_OK;
  rc = sqlite3_open (filename, &db);
  if (rc != SQLITE_OK)
    {
      fprintf (stderr, "Can't open database: %s\n", sqlite3_errmsg (db));
      sqlite3_close (db);
    }


  gchar *sql_statement;		// = g_strdup("");
  char *zErrMsg = 0;
  const char *zLeftover;
  if (db != NULL)
    {
      sql_statement = g_strdup ("SELECT * FROM 'class'");
      rc = sqlite3_exec (db, sql_statement, lessonplan_sqlite3_callback,
			 0, &zErrMsg);
      if (rc != SQLITE_OK)
	{
	  fprintf (stderr, "SQL error: %s\n", zErrMsg);
	  sqlite3_free (zErrMsg);
	}
    }


  lp_set_currentdate (lp_window_main);
  lp_setup_weekly (lp_window_main, &db);
}

void
lp_new_database (GtkWidget * lp_window_main)
{

  // int rc;
  // rc = sqlite3_open(filename, &db);
  // if( rc ){
  // fprintf(stderr, "Can't open database: %s\n", sqlite3_errmsg(db));
  // sqlite3_close(db);
  // }

  // printf();

  lp_set_currentdate (lp_window_main);
  lp_setup_weekly (lp_window_main, &db);
}

gboolean
on_window_Main_delete_event (GtkWidget * widget,
			     GdkEvent * event, gpointer user_data)
{
  sqlite3_close (db);
  gtk_main_quit ();
  return FALSE;
}


void
on_new1_activate (GtkMenuItem * menuitem, gpointer user_data)
{
  // lp_create_database();
}


void
on_open1_activate (GtkMenuItem * menuitem, gpointer user_data)
{
  GtkWidget *lp_window_main =
    lookup_widget (GTK_WIDGET (menuitem), "lp_window_main");

  if (lp_dialog_filechooser == NULL)
    {
      lp_dialog_filechooser = create_lp_dialog_filechooser ();

      GtkFileFilter *filefilter = gtk_file_filter_new ();
      gtk_file_filter_set_name (filefilter, "Lesson Plan (*.lp)");
      gtk_file_filter_add_pattern (filefilter, "*.lp");
      gtk_file_chooser_add_filter (GTK_FILE_CHOOSER
				   (lp_dialog_filechooser), filefilter);
      filefilter_selected = filefilter;

      filefilter = gtk_file_filter_new ();
      gtk_file_filter_set_name (filefilter, "All Files (*.*)");
      gtk_file_filter_add_pattern (filefilter, "*");
      gtk_file_chooser_add_filter (GTK_FILE_CHOOSER
				   (lp_dialog_filechooser), filefilter);
    }
  GtkWidget *btn_ok = lookup_widget (GTK_WIDGET (lp_dialog_filechooser),
				     "lp_dialog_filechooser_btn_ok");
  gtk_button_set_label (GTK_BUTTON (btn_ok), "gtk-open");
  gtk_button_set_use_stock (GTK_BUTTON (btn_ok), TRUE);
  gtk_file_chooser_set_action (GTK_FILE_CHOOSER (lp_dialog_filechooser),
			       GTK_FILE_CHOOSER_ACTION_OPEN);

  gtk_window_set_title (GTK_WINDOW (lp_dialog_filechooser), "Open File");
  gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (lp_dialog_filechooser),
			       filefilter_selected);

  if (gtk_dialog_run (GTK_DIALOG (lp_dialog_filechooser)) == GTK_RESPONSE_OK)
    {
      gtk_widget_hide (lp_dialog_filechooser);
      // current_filename = g_strdup_printf("");
      gchar *filename;
      filename =
	gtk_file_chooser_get_filename (GTK_FILE_CHOOSER
				       (lp_dialog_filechooser));

      lp_open_database (filename, lp_window_main);

      // read_File(filename, FormMain);
      // byoj_set_title(FALSE);
      g_free (filename);
      printf ("completed opening: %s\n", filename);
    }
  filefilter_selected =
    gtk_file_chooser_get_filter (GTK_FILE_CHOOSER (lp_dialog_filechooser));
  gtk_widget_hide (lp_dialog_filechooser);
}


void
on_save1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_save_as1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_close1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_export1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_print_preview1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_print1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_quit1_activate (GtkMenuItem * menuitem, gpointer user_data)
{
  gtk_main_quit ();
}


void
on_undo1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_redo1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_cut1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_copy1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_paste1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_delete1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_select_all1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_weekly_plans1_activate (GtkMenuItem * menuitem, gpointer user_data)
{
  GtkWidget *lp_window_lesson = create_lp_window_lesson ();
  gtk_widget_show (lp_window_lesson);
}


void
on_lesson_plans1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_standards_list1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_find1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_search_database1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_use_filter1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_edit_classes1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_preferences1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


void
on_about1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}


gboolean
on_window_Plan_delete_event (GtkWidget * widget,
			     GdkEvent * event, gpointer user_data)
{

  return FALSE;
}


void
on_choose_date1_activate (GtkMenuItem * menuitem, gpointer user_data)
{

}

void
on_calendar1_day_selected_double_click (GtkCalendar * calendar,
					gpointer user_data)
{

}


void
lp_menuitem_on_forward_week_activate (GtkMenuItem * menuitem,
				      gpointer user_data)
{
  lp_on_forward_week_activate (GTK_WIDGET (menuitem));
}


void
lp_menuitem_on_back_week_activate (GtkMenuItem * menuitem, gpointer user_data)
{
  lp_on_back_week_activate (GTK_WIDGET (menuitem));
}


void
lp_toolbtn_on_back_week_activate (GtkToolButton * toolbutton,
				  gpointer user_data)
{
  lp_on_back_week_activate (GTK_WIDGET (toolbutton));
}


void
lp_toolbtn_on_forward_week_activate (GtkToolButton * toolbutton,
				     gpointer user_data)
{
  lp_on_forward_week_activate (GTK_WIDGET (toolbutton));
}
